@@ -58,3 +58,18 @@ fn test() {
 		custom_struct: Custom::Struct{s: "foo".into(), f: 3.14},
 	});
 }
+
+#[test]
+fn key() {
+	#[derive(Debug,Eq,PartialEq,Ord,PartialOrd,serde::Deserialize)]
+	enum E { Foo, Bar, Baz, Valued(bool) }
+
+	let t: std::collections::BTreeMap<E, bool> = crate::from_bytes(b"
+		Foo: true
+		Bar: false
+	").unwrap();
+	assert_eq!(t, std::array::IntoIter::new([
+		(E::Foo, true),
+		(E::Bar, false),
+	]).collect());
+}
